@@ -1,17 +1,16 @@
+## no critic (Moose::RequireMakeImmutable)
 use 5.006;    # warnings
 use strict;
 use warnings;
 
 package MooseX::Attribute::ValidateWithException::Exception;
-BEGIN {
-  $MooseX::Attribute::ValidateWithException::Exception::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $MooseX::Attribute::ValidateWithException::Exception::VERSION = '0.3.1';
-}
+
+our $VERSION = 'v0.4.0';
 
 # ABSTRACT: An Exception object to represent "Normal" moose validation failures.
 
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
 use Moose qw( extends has );
 
 #with 'StackTrace::Auto';
@@ -75,7 +74,7 @@ MooseX::Attribute::ValidateWithException::Exception - An Exception object to rep
 
 =head1 VERSION
 
-version 0.3.1
+version v0.4.0
 
 =head1 AUTHOR
 
@@ -83,7 +82,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kent Fredric <kentnl@cpan.org>.
+This software is copyright (c) 2017 by Kent Fredric <kentnl@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
